@@ -18,24 +18,39 @@ sub parse {
     $self->{type} = substr($1, -1, 1) eq '-' ? 'ul' : 'ol';
 
     $c->htmllines("$t<$self->{type}>");
+    $self->{open} = 0;
     while (my $l = $c->nextline) {
         $l =~ /$self->{pattern}/ or last;
         if (length($1) > $self->{llevel}) {
-            $c->htmllines("$t\t<li>");
             my $node = Text::Hatena::ListNode->new(
                 context => $self->{context},
                 ilevel => $self->{ilevel},
             );
             $node->parse;
-            $c->htmllines("$t\t</li>");
         } elsif(length($1) < $self->{llevel}) {
             last;
         } else {
-            my $l = $c->shiftline;
-            $c->htmllines("$t\t<li>$2</li>");
+	    $self->_closeitem if $self->{open};
+            $c->shiftline;
+	    my $nl = $c->nextline;
+	    my $content = $2;
+	    if ($nl =~ /$self->{pattern}/ && length($1) > $self->{llevel}) {
+		$c->htmllines("$t\t<li>$content");
+		$self->{open}++;
+	    } else {
+		$c->htmllines("$t\t<li>$content</li>");
+	    }
         }
     }
+    $self->_closeitem if $self->{open};
     $c->htmllines("$t</$self->{type}>");
 }
 
+sub _closeitem {
+    my $self = shift;
+    my $t = "\t" x ($self->{ilevel} + $self->{llevel} - 1);
+    $self->{context}->htmllines("$t\t</li>");
+    $self->{open} = 0;
+}
+
 1;
